NAME
Perl::Critic::Policy::Variables::ProhibitNumericNamesWithLeadingZero - Don't use numeric variable names with leading zeros.
AFFILIATION
This Policy is stand-alone, and is not part of the core Perl::Critic.
DESCRIPTION
Numeric variable names with leading zeros are unsupported by Perl, and can lead to obscure bugs. In particular, they are not (or not straightforwardly) accessible as ${0nnn}.
Starting with Perl 5.32, these variables represent a syntax error, so this policy is useless with current Perls. On the other hand, it may be useful for those with an older code base, especially if they are preparing to upgrade it.
CONFIGURATION
This policy supports no configuration items above and beyond the standard ones.
SUPPORT
Support is by the author. Please file bug reports at https://github.com/trwyant/perl-Perl-Critic-Policy-Variables-ProhibitNumericNamesWithLeadingZero/issues or in electronic mail to the author.
AUTHOR
Thomas R. Wyant, III harryfmudd at comcast dot net
COPYRIGHT
Copyright (C) 2022, 2026 Thomas R. Wyant, III
LICENSE
This program is free software; you can redistribute it and/or modify it under the same terms as Perl 5.10.0. For more details, see the full text of the licenses in the files LICENSE-Artistic and LICENSE-GPL.
This program is distributed in the hope that it will be useful, but without any warranty; without even the implied warranty of merchantability or fitness for a particular purpose.